@@ -302,6 +302,7 @@ def django_to_cache(
     async def run_django_to_cache(
             redis_root,
             django_model,
+            django_fields,
             cache_conf,
     ):
         filter_by = cache_conf['filter_by']
@@ -321,6 +322,7 @@ def django_to_cache(
                     update_or_create_redis_instance_from_django_instance(
                         redis_root,
                         django_instance,
+                        django_fields,
                         all_redis_instances,
                         cache_conf,
                     )
@@ -351,11 +353,14 @@ def django_to_cache(
         print(f'{datetime.datetime.now()} - '
               f'Deleted {django_model} instances from cache')
 
+    django_fields = django_model._meta.get_fields()
+
     loop = asyncio.get_event_loop()
     loop.run_until_complete(
         run_django_to_cache(
             redis_root,
             django_model,
+            django_fields,
             cache_conf,
         )
     )
@@ -364,6 +369,7 @@ def django_to_cache(
 async def update_or_create_redis_instance_from_django_instance(
         redis_root,
         django_instance,
+        django_fields,
         all_redis_instances,
         cache_conf,
 ):
@@ -376,9 +382,10 @@ async def update_or_create_redis_instance_from_django_instance(
     redis_dict = await django_instance_to_redis_params(
         redis_root,
         django_instance,
+        django_fields,
         cache_conf,
     )
-
+    print(django_instance_model, django_instance.id)
     if not old_redis_instance:
         fields_to_create = redis_dict
         redis_instance = redis_root.create(
@@ -486,12 +493,13 @@ async def django_instance_field_to_redis_value(
 async def django_instance_to_redis_params(
         redis_root,
         django_instance,
+        django_fields,
         cache_conf,
 ):
 
     redis_params = {}
     exclude_fields = cache_conf['exclude_fields']
-    django_fields = django_instance.__class__._meta.get_fields()
+
     for i, django_field in enumerate(django_fields):
         if not django_field.__class__.__name__.endswith('Rel'):
             django_field_name = django_field.name
@@ -537,6 +545,7 @@ async def get_or_create_redis_instance_from_django_instance(
         all_redis_instances,
         cache_conf,
 ):
+    django_fields = django_instance.__class__._meta.get_fields()
 
     redis_instance = get_redis_instance_by_django_id_from_all_redis_instances(
         django_instance.id,
@@ -549,6 +558,7 @@ async def get_or_create_redis_instance_from_django_instance(
             redis_root,
             django_instance,
             cache_conf,
+            django_fields,
         )
         redis_instance = redis_root.create(
             django_model=django_instance_model,
