@@ -407,9 +407,6 @@ class RedisRoot:
             save_consistency=False,
             economy=False,
     ):
-        self.performance = {
-            'enabled': False,
-        }
         self.registered_models = []
         self.registered_django_models = {}
         if type(prefix) == str:
@@ -568,15 +565,6 @@ class RedisRoot:
         return new_redis_model
 
     def get_or_create_redis_model_from_django_model(self, django_model):
-        if self.performance['enabled']:
-            if 'get_or_create_redis_model_from_django_model' not in self.performance.keys():
-                self.performance['get_or_create_redis_model_from_django_model'] = {
-                    'requests': 0,
-                    'time': 0
-                }
-            self.performance['get_or_create_redis_model_from_django_model']['requests'] += 1
-            started_in = datetime.datetime.now()
-
         cache_conf = self.get_cache_conf(django_model)
         save_related_models = cache_conf['save_related_models']
         exclude_fields = cache_conf['exclude_fields']
@@ -588,14 +576,9 @@ class RedisRoot:
             new_redis_model = self.update_redis_model_from_redis_fields(django_model, existing_redis_model, redis_fields)
         else:
             new_redis_model = self.create_redis_model_from_redis_fields(django_model, redis_fields)
-        ended_in = datetime.datetime.now()
-        if self.performance['enabled']:
-            self.performance['get_or_create_redis_model_from_django_model']['time'] += (ended_in-started_in).total_seconds()
-
         return new_redis_model
 
     def check_cache(self):
-        self.performance['enabled'] = True
         django_models_to_cache = self._get_django_models_to_cache()
         for django_model, cache_conf in django_models_to_cache.items():
 
@@ -613,15 +596,6 @@ class RedisRoot:
             print(f'{datetime.datetime.now()} - '
                   f'Cached {django_model} successfully'
                   f'\n\n\n')
-            if self.performance['enabled']:
-                print('Performance')
-                for func_name, performance_data in self.performance.items():
-                    if func_name != 'enabled':
-                        print(f'\n'
-                              f'{func_name}\n'
-                              f'Requests: {performance_data["requests"]}\n'
-                              f'Time: {performance_data["time"]}s\n'
-                              f'Per request: {performance_data["time"]/performance_data["requests"]}s')
 
 
     def fast_get_keys_values(self, string):
@@ -917,15 +891,6 @@ class RedisRoot:
         return allowed
 
     def _get_instances_by_key(self, key):
-        if self.performance['enabled']:
-            if '_get_instances_by_key' not in self.performance.keys():
-                self.performance['_get_instances_by_key'] = {
-                    'requests': 0,
-                    'time': 0
-                }
-            self.performance['_get_instances_by_key']['requests'] += 1
-            started_in = datetime.datetime.now()
-
         raw_instances = self.fast_get_keys_values(key)
         instances = {}
         for instance_key, fields_json in raw_instances.items():
@@ -937,9 +902,6 @@ class RedisRoot:
                 if instance_id not in instances.keys():
                     instances[instance_id] = {}
                 instances[instance_id][field_name] = value
-        if self.performance['enabled']:
-            ended_in = datetime.datetime.now()
-            self.performance['_get_instances_by_key']['time'] += (ended_in - started_in).total_seconds()
         return instances
 
     def _get_all_stored_model_instances(self, redis_model, filters=None):
@@ -992,19 +954,8 @@ class RedisRoot:
         return self._return_with_format(instances, return_dict)
 
     def get(self, django_model, return_dict=False, **filters):
-        if self.performance['enabled']:
-            if 'get' not in self.performance.keys():
-                self.performance['get'] = {
-                    'requests': 0,
-                    'time': 0
-                }
-            self.performance['get']['requests'] += 1
-            started_in = datetime.datetime.now()
         redis_model = self._django_model_to_redis_model(django_model)
         result = self.get_by_redis_model(redis_model, return_dict, **filters)
-        if self.performance['enabled']:
-            ended_in = datetime.datetime.now()
-            self.performance['get']['time'] += (ended_in - started_in).total_seconds()
         return result
 
     def order(self, instances, field_name):
@@ -1058,14 +1009,6 @@ class RedisRoot:
         return updated_data
 
     def update(self, django_model, instances=None, return_dict=False, renew_ttl=False, new_ttl=None, **fields_to_update):
-        if self.performance['enabled']:
-            if 'update' not in self.performance.keys():
-                self.performance['update'] = {
-                    'requests': 0,
-                    'time': 0
-                }
-            self.performance['update']['requests'] += 1
-            started_in = datetime.datetime.now()
         model = self._django_model_to_redis_model(django_model)
         model_name = model.__name__
         updated_datas = []
@@ -1092,9 +1035,6 @@ class RedisRoot:
                 updated_instance = updated_instance_qs[0]
                 updated_instances[updated_id] = updated_instance
         result = self._return_with_format(updated_instances, return_dict)
-        if self.performance['enabled']:
-            ended_in = datetime.datetime.now()
-            self.performance['update']['time'] += (ended_in - started_in).total_seconds()
         return result
 
     def _delete_by_key(self, key):
@@ -1134,20 +1074,8 @@ class RedisRoot:
     #     return result
 
     def create(self, django_model, **params):
-        if self.performance['enabled']:
-            if 'create' not in self.performance.keys():
-                self.performance['create'] = {
-                    'requests': 0,
-                    'time': 0
-                }
-            self.performance['create']['requests'] += 1
-            started_in = datetime.datetime.now()
-
         redis_model = self._django_model_to_redis_model(django_model)
         redis_instance = redis_model(redis_root=self, **params).save()
-        if self.performance['enabled']:
-            ended_in = datetime.datetime.now()
-            self.performance['create']['time'] += (ended_in - started_in).total_seconds()
         return redis_instance
 
 
